@@ -20,7 +20,7 @@ PEXPECT LICENSE
 '''
 import pexpect
 import unittest
-import PexpectTestCase
+from . import PexpectTestCase
 
 class MissingCommandTestCase (PexpectTestCase.PexpectTestCase):
     def testMissingCommand(self):
